@@ -3,11 +3,12 @@
 #define GOPHER_GROUP "gopher"
 #define LOGLEVEL DEBUG
 
-#ifndef GOPHER_HOST
-#define GOPHER_HOST "localhost"
-#endif // GOPHER_HOST
+// Windows can't understand low ports because you won't be root.
+#ifndef _WIN32
 #define GOPHER_PORT "70"
-
+#else
+#define GOPHER_PORT "7070"
+#endif // _WIN32
 
 /*
  * For your reference, the relevant Gopher file types. Only 0 and 9 are supported right now:
@@ -24,5 +25,7 @@ static const struct mapping mappings[] = {
     {.extension = ".tar.xz", .filetype = '9'},
     {.extension = ".tar",    .filetype = '9'},
     {.extension = ".txt",    .filetype = '0'},
-    {.extension = ".map",    .filetype = '1'}
+    {.extension = ".map",    .filetype = '1'},
+    {.extension = ".jpg",    .filetype = 'I'},
+    {.extension = ".jpeg",    .filetype = 'I'}
 };
